==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/submit.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
KWL_CheckLocalReferer(1);

switch ($what) {
case "comment":

   $Content = trim($Content);
	if (empty($Content) || !KWL_HcodeCheck($ParentRid.$TopRid,$hcode)) {
      KWL_ShowError(_ERROR_INPUT);
   }
	
   if (!empty($anon) && $CONF['AllowAnon']) { 
		$Author = "Anonymous"; $AuthorEmail=""; $AuthorURL=""; $score = 0;
	} else {
      $anon = "";
      if ($CONF['NoLogin_User']) {
         $AuthorEmail = KWL_EmailCheck($AuthorEmail);
         $AuthorURL = KWL_UrlCheck($AuthorURL);
         if (empty($Author) || empty($AuthorEmail)) KWL_ShowError(_ERROR_INPUT);
         else KWL_SaveUserCookie($Author,$AuthorEmail,$AuthorURL);
      } elseif ($login && is_array($user)) {
         $AuthorEmail = $user['email']; $AuthorURL = $user['url']; $Author = $user['name'];
      } else {
         KWL_ShowError(_ERROR_INPUT);
      }
	}
   
   if (!$CONF['ENABLE_FACE'] || !in_array($faceicon, KWL_GetFileName("$CONF[G_PATH]/images.d/face"))) $faceicon = "";
   
   if ($mode == _PREVIEW) {
      $head = _PREVIEW;
      include("include/header.inc.php");
      $_POST['Birthstamp'] = date("Y-m-d H:i:s",time());
      $_POST['Host'] = KWL_GetIP();
      $_POST['Author'] = $Author;
      $_POST['AuthorEmail'] = $AuthorEmail;
      $_POST['AuthorURL'] = $AuthorURL;
      $_POST['face'] = $faceicon;
      $_POST['Rid'] = "";
      if (!empty($anon)) $_POST['score'] = 0;
      else $_POST['score'] = 1;
      $_POST = KWL_string_parse($_POST,"stripslashes");
      KWL_DrawComment($_POST,'',1);

      $out = new KWL_Html;	
		$VAR['Content'] = $out->form_start("submit.php","Com")
         . $out->table_start("100%",'',0,0,3);

      if ($CONF['NoLogin_User']) {
         
         $VAR['Content'] .= $out->input_form("HIDDEN","Author",$Author).
                          $out->input_form("HIDDEN","AuthorEmail",$AuthorEmail).
                          $out->input_form("HIDDEN","AuthorURL",$AuthorURL).
                          $out->input_form("HIDDEN","anon",$anon);
      
      } else {
         if ($login) {
            $VAR['Content'] .= "<TR><TD>" . _NAME . ":</TD>" .
                             "<TD><A HREF=\"$CONF[G_URL]/user.php\">". KWL_PrepareHtml($user['name']) ."</A> (#$user[uid])</TD>\n";
            if ($CONF['AllowAnon'])
               $VAR['Content'] .= "<TR><TD>". _ANONYMOUS .": </TD>". 
                                "<TD>". $out->check_box("anon",$anon) ."</TD></TR>";
            if ($CONF['EmailReply']) 
               if (!empty($ereply)) $ereply = 1;
               else $ereply = 0;            
               $VAR['Content'] .= "<TR><TD>". _MAILCOMMENTS .": </TD>" . 
                                "<TD>". $out->check_box("ereply",$ereply) ."</TD></TR>";
            
         } else {
            $VAR['Content'] .= "<TD COLSPAN=2>";

            if ($CONF['AllowAnon']) {
               $VAR['Content'] .= $out->input_form("HIDDEN","anon","on") .
                                _NEED_LOGIN . "</TD></TR>\n";
               
            } else {
               $VAR["Content"] .= _NO_POST . "</TD></TR></FORM></TABLE>\n";
               KWL_DrawMain($VAR);
               return;
               
            }
         }
      }
		if ($CONF['ENABLE_FACE']) {
			$VAR["Content"] .= "<tr><td>". _FACE .": </td><td>". $out->input_form("text","faceicon","$faceicon",KWL_FormSize(5),128) ." <font size=\"-1\">(<a href=\"$CONF[G_URL]/viewimg.php?path=images.d/face&form=Com&var=faceicon\" target=\"_new\" onClick=\"new_windows('$CONF[G_URL]/viewimg.php?path=images.d/face&form=Com&var=faceicon','viewicon',1,1,580,580); return false\">"._VIEW_FACE."</a>)</font></td>\n";
		}
		$VAR["Content"] .= "<TR><TD COLSPAN=2>". _COMMENT .": ". 
         KWL_FormResizer("Com.Content",$size['text'],10) ."<BR>".
         $out->textarea("Content",10,$size['text'],KWL_PrepareHtml(stripslashes($Content))) ."
         <BR>". KWL_MakeSelectParse($CONF['reply_parse'],$ParseLevel) .
         "</TD></TR><TR><TD COLSPAN=2>";
      settype($passwd, "string");
      settype($uscore, "string");
      $VAR["Content"] .= $out->input_form("HIDDEN","hcode",KWL_HcodeMake($ParentRid.$TopRid)) .
                         $out->input_form("HIDDEN","uscore",$uscore) .
                         $out->input_form("HIDDEN","passwd",$passwd) .
                         $out->input_form("HIDDEN","what","comment") .
                         $out->input_form("HIDDEN","ParentRid",$ParentRid) .
                         $out->input_form("HIDDEN","TopRid",$TopRid) .
                         $out->input_form("HIDDEN","where",$where) .
                         $out->input_form("SUBMIT","mode",_PREVIEW) .
                         $out->input_form("SUBMIT","mode",_SUBMIT);
		$VAR["Content"] .= "</TD></TR>". $out->table_end() . $out->form_end();
		$VAR["Heading"] = _POSTCOMMENT .": ". _PREVIEW;
		KWL_DrawMain($VAR);
      include("include/footer.inc.php");
      exit;
   }

	if (!empty($user['user_sig']) && empty($anon))
      $Content .= "\n-- \n" . addslashes($user['user_sig']);
   if ($Author && $AuthorEmail) $score = 1;
   if ($CONF['ENABLE_CEDIT'] && !$login) $passwd = crypt($passwd);
   else $passwd = $user['pass'];
   if (empty($Author) || empty($Content) || empty($ParentRid) || empty($TopRid)) {
      KWL_ShowError(_ERROR_INPUT);
   }
   FWL_CheckDuplePost($Content,$Author,"T_Comments");
   if ($CONF['SPAM_CHECK']==1) KWL_SpamCheck($Content,$Author,$AuthorEmail);
   elseif ($CONF['SPAM_CHECK']==2) $Content = KWL_ProofSpam($Content);
   $Author = KWL_PrepareHtml($Author);

   if ($CONF['reply_parse']) {
      if ($ParseLevel < 2 || $ParseLevel > 4) $ParseLevel = $CONF['Reply_PLevel'];
   } else $ParseLevel = $CONF['Reply_PLevel'];

   $crid = KWL_getRid();
   $sql	= "INSERT INTO T_Comments ";
   $sql	.= "(Rid,ParentRid,TopRid,Author,AuthorEmail,AuthorURL,Content,Host,Birthstamp,passwd,face,score,email,ParseLevel) ";
   $sql	.= "VALUES (";
   $sql	.= "'$crid',";
   $sql	.= "'$ParentRid', '$TopRid', '$Author', '$AuthorEmail',";
   $sql	.= "'$AuthorURL', '$Content',";
   $sql	.= "'" . KWL_GetIP() . "', now(), '$passwd', '$faceicon', $score,";
   $sql  .= ($ereply == "on" ? "1" : "0") . ", $ParseLevel)";
   if (SqlQuery($sql)) {
      if (eregi("story",$where)) {
         SqlQuery("LOCK TABLES T_Stories WRITE");
         SqlQuery("UPDATE T_Stories SET replys = replys + 1, lastrdate = now() WHERE Rid = '$TopRid'");
         SqlQuery("UNLOCK TABLES");
      }
      if ($uscore) {
         if ($uscore == "plus") $tmp = "+ 1";
         else $tmp = "- 1";
         $sql  = "UPDATE T_Comments SET score = score $tmp ";
         $sql .= "WHERE Rid = '$ParentRid'";
         SqlQuery($sql);
      }
      if ($Author == "Anonymous" && empty($AuthorEmail)) $Author = _ANONY;
      if ($CONF['EmailComments']) register_shutdown_function(KWL_MailThread($TopRid,$Author,$Content,$AuthorEmail,$where,$crid));
      if ($CONF['CATCH_REPLYS']) register_shutdown_function(KWL_CommentToAdmin($TopRid,$Author,$Content,$AuthorEmail,$where,$crid));
      if ($CONF['EmailReply']) register_shutdown_function(KWL_MailReply($ParentRid,$Author,$Content,$AuthorEmail,$where,$crid,$TopRid));
      KWL_Redirect("$where#$crid");
   } else {
      KWL_ErrorLog(_UNABLE_COMMENT);
      KWL_ShowError(_SQL_ERROR);
   }
break;

case "contact":

	$tmp	= urlencode(_MAILERROR);
	$AuthorEmail = KWL_EmailCheck($AuthorEmail);
	$Message = trim($Message);
	if ($Author && $AuthorEmail && $Subject && $Message) {
		$Author = stripslashes($Author);
		$ret = new email (stripslashes($Subject),stripslashes($Message),stripslashes($Author), $AuthorEmail, $MailTo ." <". $MailToEmail .">");
		if ($ret) $tmp	= urlencode(_MAILSENT);
		else KWL_ErrorLog(_MAILERROR);
		KWL_Redirect("stories.php?msg=$tmp");
	} else {
		KWL_ShowError(_ERROR_INPUT);
	}

break;

case "mailfriend":

	$AuthorEmail = KWL_EmailCheck($AuthorEmail);
	$MailToEmail = KWL_EmailCheck($MailToEmail);
	if (!$Author || !$MailTo || !$AuthorEmail || !$Story || !$MailToEmail) {
		KWL_ShowError(_ERROR_INPUT);
	} else {
		KWL_MailFriend($Story,$MailToEmail,$Author,$AuthorEmail,$Message);
		KWL_Redirect("stories.php?story=$Story&msg=" . urlencode(_MAILSENT));
	}
break;

case "scorechange":

	if (KWL_CheckAdmin() || ($login && $user[user_level] == 2)) {
		if ($rid) {	
			if ($act == "plus") $tmp = "+ 1";
			else $tmp = "- 1";
			$sql  = "UPDATE T_Comments SET score = score " . $tmp;
			$sql .= " WHERE Rid = '$rid'";
			SqlQuery($sql);
			$A = SqlQueryFetchArray("SELECT ParentRid,TopRid FROM T_Comments WHERE Rid = '$rid'");
		}
		$where = "comments.php?rid=$A[ParentRid]&story=$A[TopRid]#$rid";
		KWL_Redirect(urldecode($where));
	} else echo "Hey! WTF !?";
break;

default:
	KWL_Redirect("$CONF[G_URL]");
}
?>

==> korweblog-1.5.9.tar.gz: korweblog-1.5.9/submit.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
KWL_CheckLocalReferer(1);

switch ($what) {
case "comment":

   $Content = trim($Content);
	if (empty($Content) || !KWL_HcodeCheck($ParentRid.$TopRid,$hcode)) {
      KWL_ShowError(_ERROR_INPUT);
   }
	
   if (!empty($anon) && $CONF['AllowAnon']) { 
		$Author = "Anonymous"; $AuthorEmail=""; $AuthorURL=""; $score = 0;
	} else {
      $anon = "";
      if ($CONF['NoLogin_User']) {
         $AuthorEmail = KWL_EmailCheck($AuthorEmail);
         $AuthorURL = KWL_UrlCheck($AuthorURL);
         if (empty($Author) || empty($AuthorEmail)) KWL_ShowError(_ERROR_INPUT);
         else KWL_SaveUserCookie($Author,$AuthorEmail,$AuthorURL);
      } elseif ($login && is_array($user)) {
         $AuthorEmail = $user['email']; $AuthorURL = $user['url']; $Author = $user['name'];
      } else {
         KWL_ShowError(_ERROR_INPUT);
      }
	}
   
   if (!$CONF['ENABLE_FACE'] || !in_array($faceicon, KWL_GetFileName("$CONF[G_PATH]/images.d/face"))) $faceicon = "";
   
   if ($mode == _PREVIEW) {
      $head = _PREVIEW;
      include("include/header.inc.php");
      $_POST['Birthstamp'] = date("Y-m-d H:i:s",time());
      $_POST['Host'] = KWL_GetIP();
      $_POST['Author'] = $Author;
      $_POST['AuthorEmail'] = $AuthorEmail;
      $_POST['AuthorURL'] = $AuthorURL;
      $_POST['face'] = $faceicon;
      $_POST['Rid'] = "";
      if (!empty($anon)) $_POST['score'] = 0;
      else $_POST['score'] = 1;
      $_POST = KWL_string_parse($_POST,"stripslashes");
      KWL_DrawComment($_POST,'',1);

      $out = new KWL_Html;	
		$VAR['Content'] = $out->form_start("submit.php","Com")
         . $out->table_start("100%",'',0,0,3);

      if ($CONF['NoLogin_User']) {
         
         $VAR['Content'] .= $out->input_form("hidden","Author",$Author).
                          $out->input_form("hidden","AuthorEmail",$AuthorEmail).
                          $out->input_form("hidden","AuthorURL",$AuthorURL).
                          $out->input_form("hidden","anon",$anon);
      
      } else {
         if ($login) {
            $VAR['Content'] .= "<tr><td>" . _NAME . ":</td>" .
                             "<td><a href=\"$CONF[G_URL]/user.php\">". KWL_PrepareHtml($user['name']) ."</a> (#$user[uid])</td>\n";
            if ($CONF['AllowAnon'])
               $VAR['Content'] .= "<tr><td>". _ANONYMOUS .": </td>". 
                                "<td>". $out->check_box("anon",$anon) ."</td></tr>";
            if ($CONF['EmailReply']) 
               if (!empty($ereply)) $ereply = 1;
               else $ereply = 0;            
               $VAR['Content'] .= "<tr><td>". _MAILCOMMENTS .": </td>" . 
                                "<td>". $out->check_box("ereply",$ereply) ."</td></tr>";
            
         } else {
            $VAR['Content'] .= "<td colspan=\"2\">";

            if ($CONF['AllowAnon']) {
               $VAR['Content'] .= $out->input_form("hidden","anon","on") .
                  sprintf(_NEED_LOGIN,
                        "<a href=\"$CONF[G_URL]/login.php\">"._LOGIN."</a>",
                        "<a href=\"$CONF[G_URL]/login.php\">"._UREGITER."</a>") . "</td></tr>\n";
               
            } else {
               $VAR["Content"] .= _NO_POST . "</td></tr></form></table>\n";
               KWL_DrawMain($VAR);
               return;
               
            }
         }
      }
		if ($CONF['ENABLE_FACE']) {
			$VAR["Content"] .= "<tr><td>". _FACE .": </td><td>". $out->input_form("text","faceicon","$faceicon",KWL_FormSize(5),128) ." (<a href=\"$CONF[G_URL]/viewimg.php?path=images.d/face&form=Com&var=faceicon\" target=\"_new\" onClick=\"new_windows('$CONF[G_URL]/viewimg.php?path=images.d/face&form=Com&var=faceicon','viewicon',1,1,580,580); return false\">"._VIEW_FACE."</a>)</td>\n";
		}
		$VAR["Content"] .= "<tr><td colspan=\"2\">". _COMMENT .": ". 
         KWL_FormResizer("Com.Content",$size['text'],10) ."<br />".
         $out->textarea("Content",10,$size['text'],KWL_PrepareHtml(stripslashes($Content))) ."
         <br />". KWL_MakeSelectParse($CONF['reply_parse'],$ParseLevel) .
         "</td></tr><tr><td colspan=\"2\">";
      settype($passwd, "string");
      settype($uscore, "string");
      $VAR["Content"] .= $out->input_form("hidden","hcode",KWL_HcodeMake($ParentRid.$TopRid)) .
                         $out->input_form("hidden","uscore",$uscore) .
                         $out->input_form("hidden","passwd",$passwd) .
                         $out->input_form("hidden","what","comment") .
                         $out->input_form("hidden","ParentRid",$ParentRid) .
                         $out->input_form("hidden","TopRid",$TopRid) .
                         $out->input_form("hidden","where",$where) .
                         $out->input_form("submit","mode",_PREVIEW) .
                         $out->input_form("submit","mode",_SUBMIT);
		$VAR["Content"] .= "</td></tr>". $out->table_end() . $out->form_end();
		$VAR["Heading"] = _POSTCOMMENT .": ". _PREVIEW;
		KWL_DrawMain($VAR);
      include("include/footer.inc.php");
      exit;
   }

	if (!empty($user['user_sig']) && empty($anon))
      $Content .= "\n-- \n" . addslashes($user['user_sig']);
   if ($Author && $AuthorEmail) $score = 1;
   if ($CONF['ENABLE_CEDIT'] && !$login) $passwd = crypt($passwd);
   else $passwd = $user['pass'];
   if (empty($Author) || empty($Content) || empty($ParentRid) || empty($TopRid)) {
      KWL_ShowError(_ERROR_INPUT);
   }
   FWL_CheckDuplePost($Content,$Author,"T_Comments");
   if ($CONF['BLOCK_IP']) KWL_PostBlockIP($Content,$Author,$AuthorEmail);
   elseif ($CONF['SPAM_CHECK']==1) KWL_SpamCheck($Content,$Author,$AuthorEmail);
   elseif ($CONF['SPAM_CHECK']==2) $Content = KWL_ProofSpam($Content);
   $Author = KWL_PrepareHtml($Author);

   if ($CONF['reply_parse']) {
      if ($ParseLevel < 2 || $ParseLevel > 4) $ParseLevel = $CONF['Reply_PLevel'];
   } else $ParseLevel = $CONF['Reply_PLevel'];

   $crid = KWL_getRid();
   $sql	= "INSERT INTO T_Comments ";
   $sql	.= "(Rid,ParentRid,TopRid,Author,AuthorEmail,AuthorURL,Content,Host,Birthstamp,passwd,face,score,email,ParseLevel) ";
   $sql	.= "VALUES (";
   $sql	.= "'$crid',";
   $sql	.= "'$ParentRid', '$TopRid', '$Author', '$AuthorEmail',";
   $sql	.= "'$AuthorURL', '$Content',";
   $sql	.= "'" . KWL_GetIP() . "', now(), '$passwd', '$faceicon', $score,";
   $sql  .= ($ereply == "on" ? "1" : "0") . ", $ParseLevel)";
   if (SqlQuery($sql)) {
      if (eregi("story",$where)) {
         SqlQuery("LOCK TABLES T_Stories WRITE");
         SqlQuery("UPDATE T_Stories SET replys = replys + 1, lastrdate = now() WHERE Rid = '$TopRid'");
         SqlQuery("UNLOCK TABLES");
      }
      if ($uscore && $CONF['AllowScore'] && $CONF['SCORING']) {
         if ($uscore == "plus") $tmp = "+ 1";
         elseif ($uscore == "minus") $tmp = "- 1";
         $sql  = "UPDATE T_Comments SET score = score $tmp ";
         $sql .= "WHERE Rid = '$ParentRid'";
         SqlQuery($sql);
      }
      if ($Author == "Anonymous" && empty($AuthorEmail)) $Author = _ANONY;
      if ($CONF['EmailComments']) register_shutdown_function(KWL_MailThread($TopRid,$Author,$Content,$AuthorEmail,$where,$crid));
      if ($CONF['CATCH_REPLYS']) register_shutdown_function(KWL_CommentToAdmin($TopRid,$Author,$Content,$AuthorEmail,$where,$crid));
      if ($CONF['EmailReply']) register_shutdown_function(KWL_MailReply($ParentRid,$Author,$Content,$AuthorEmail,$where,$crid,$TopRid));
      KWL_Redirect("$where#$crid");
   } else {
      KWL_ErrorLog(_UNABLE_COMMENT);
      KWL_ShowError(_SQL_ERROR);
   }
break;

case "contact":

	$tmp	= urlencode(_MAILERROR);
	$AuthorEmail = KWL_EmailCheck($AuthorEmail);
	$Message = trim($Message);
	if ($Author && $AuthorEmail && $Subject && $Message) {
		$Author = stripslashes($Author);
		$ret = new email (stripslashes($Subject),stripslashes($Message),stripslashes($Author), $AuthorEmail, $MailTo ." <". $MailToEmail .">");
		if ($ret) $tmp	= urlencode(_MAILSENT);
		else KWL_ErrorLog(_MAILERROR);
		KWL_Redirect("stories.php?msg=$tmp");
	} else {
		KWL_ShowError(_ERROR_INPUT);
	}

break;

case "mailfriend":

	$AuthorEmail = KWL_EmailCheck($AuthorEmail);
	$MailToEmail = KWL_EmailCheck($MailToEmail);
	if (!$Author || !$MailTo || !$AuthorEmail || !$Story || !$MailToEmail) {
		KWL_ShowError(_ERROR_INPUT);
	} else {
		KWL_MailFriend($Story,$MailToEmail,$Author,$AuthorEmail,$Message);
		KWL_Redirect("stories.php?story=$Story&msg=" . urlencode(_MAILSENT));
	}
break;

case "scorechange":

	if (KWL_CheckAdmin() || ($login && $user['user_level'] == 2)) {
		if ($rid) {	
			if ($act == "plus") $tmp = "+ 1";
			else $tmp = "- 1";
			$sql  = "UPDATE T_Comments SET score = score " . $tmp;
			$sql .= " WHERE Rid = '$rid'";
			SqlQuery($sql);
			$A = SqlQueryFetchArray("SELECT ParentRid,TopRid FROM T_Comments WHERE Rid = '$rid'");
		}
		$where = "comments.php?rid=$A[ParentRid]&story=$A[TopRid]#$rid";
		KWL_Redirect(urldecode($where));
	} else echo "Hey! WTF !?";
break;

default:
	KWL_Redirect("$CONF[G_URL]");
}
?>
